package com.ruoyi.tcZz.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcZdgzxm;
import com.ruoyi.tcZz.domain.TcZdlyjg;
import com.ruoyi.tcZz.service.ITcZdlyjgService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 重点领域监管Controller
 *
 * @author ruoyi
 * @date 2023-10-13
 */
@RestController
@Api(tags = "重点领域监管")
@RequestMapping("/tcZz/netManage/zdlyjg")
public class TcZdlyjgController extends BaseController {
    @Autowired
    private ITcZdlyjgService tcZdlyjgService;

    /**
     * 查询重点领域监管列表
     */
    @ApiOperation(value = "查询重点领域监管列表", response = TcZdlyjg.class)
    @GetMapping("/list")
    public TableDataInfo list(TcZdlyjg tcZdlyjg) {
        startPage();
        List<TcZdlyjg> list = tcZdlyjgService.selectTcZdlyjgList(tcZdlyjg);
        return getDataTable(list);
    }

    /**
     * 导出重点领域监管列表
     */
    @ApiOperation(value = "导出重点领域监管列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZdlyjg tcZdlyjg) {
        List<TcZdlyjg> list = tcZdlyjgService.selectTcZdlyjgList(tcZdlyjg);
        ExcelUtil<TcZdlyjg> util = new ExcelUtil<TcZdlyjg>(TcZdlyjg.class);
        util.exportExcel(response, list, "重点领域监管数据");
    }

    /**
     * 获取重点领域监管详细信息
     */
    @ApiOperation(value = "获取重点领域监管详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcZdlyjgService.selectTcZdlyjgById(id));
    }

    /**
     * 新增重点领域监管
     */
    @ApiOperation(value = "新增重点领域监管")
    @PostMapping
    public AjaxResult add(@RequestBody TcZdlyjg tcZdlyjg) {
        return toAjax(tcZdlyjgService.insertTcZdlyjg(tcZdlyjg));
    }

    /**
     * 修改重点领域监管
     */
    @ApiOperation(value = "修改重点领域监管")
    @PutMapping
    public AjaxResult edit(@RequestBody TcZdlyjg tcZdlyjg) {
        return toAjax(tcZdlyjgService.updateTcZdlyjg(tcZdlyjg));
    }

    /**
     * 删除重点领域监管
     */
    @ApiOperation(value = "删除重点领域监管")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcZdlyjgService.deleteTcZdlyjgByIds(ids));
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcZdlyjg> util = new ExcelUtil<TcZdlyjg>(TcZdlyjg.class);
        List<TcZdlyjg> tcZdlyjgList = util.importExcel(file.getInputStream());
        tcZdlyjgService.importUser(tcZdlyjgList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcZdlyjgService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcZdlyjg> util = new ExcelUtil<TcZdlyjg>(TcZdlyjg.class);
        util.importTemplateExcel(response, " 重点领域监管");
    }
}
